==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Gegenwärtiges Spiel abbrechen?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pausiert&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klicken Sie um das Spiel fortzusetzen.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Spiel vorbei!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klicken Sie um ein neues Spiel zu starten.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet Punkte</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Reihen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klicken Sie um ein neues Spiel zu starten.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Fortsetzen</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Punkte</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Anwendungssprache...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Info über &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Nächster Stein</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Entfernte Reihen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Ein Tetris-Klon, den ich für meine Frau gemacht habe</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
</TS>

==> gottet_1.2.0.orig.tar.gz: gottet-1.2.0/translations/gottet_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Gegenwärtiges Spiel abbrechen?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pausiert&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klicken Sie um das Spiel fortzusetzen.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Spiel vorbei!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klicken Sie um ein neues Spiel zu starten.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Reihen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klicken Sie um ein neues Spiel zu starten.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Punkte</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Anwendungssprache...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Info über &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Nächster Stein</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Entfernte Reihen</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
